pub struct PauseGateHandle { /* private fields */ }Expand description
Pauses and resumes a PauseGate from another thread.
Cloneable and cheap: the thread that owns a button and the one that owns the element are never the same.
Implementations