pub struct ThreadSpawnError { /* private fields */ }Expand description
Failure to create one of the background threads owned by this crate.
The operation that requested the thread returns this error before claiming
that it started successfully. The thread field identifies the worker so
callers can distinguish pipeline, queue, and standalone-driver failures.
Implementations