pub struct PortRef {
pub element: ElementId,
pub port: Arc<str>,
}Expand description
One end of an edge: the element, and the name of the pad on it.
Fields
element: ElementIdStable identity of the element that owns this port.
port: Arc<str>Element-defined port name used in topology output.