pub struct SwVideoCompositorInput {
pub sink: Box<dyn Sink>,
pub layer: SwVideoLayerHandle,
}Expand description
The two endpoints created for one compositor input registration.
Move sink into the upstream pipeline and retain layer in application
code for runtime placement changes.
Fields
sink: Box<dyn Sink>layer: SwVideoLayerHandleAuto Trait Implementations
impl !RefUnwindSafe for SwVideoCompositorInput
impl !Sync for SwVideoCompositorInput
impl !UnwindSafe for SwVideoCompositorInput
impl Freeze for SwVideoCompositorInput
impl Send for SwVideoCompositorInput
impl Unpin for SwVideoCompositorInput
impl UnsafeUnpin for SwVideoCompositorInput